"""Script for running tsunami inundation scenario for Karratha, WA, Australia.

Source data such as elevation and boundary data is assumed to be available in
directories specified by project.py
The output sww file is stored in project.outputtimedir 

The scenario is defined by a triangular mesh created from project.polygon,
the elevation data and a simulated submarine landslide.

Ole Nielsen and Duncan Gray, GA - 2005 and Jane Sexton, Nick Bartzis, GA - 2006
"""

#------------------------------------------------------------------------------
# Import necessary modules
#------------------------------------------------------------------------------

# Standard modules
from os import sep
from os.path import dirname, basename
from os import mkdir, access, F_OK
from shutil import copy
import time
import sys


# Related major packages
from anuga.shallow_water import Domain
from anuga.shallow_water import Dirichlet_boundary
from anuga.shallow_water import File_boundary
from anuga.shallow_water import Reflective_boundary

from anuga.pmesh.mesh_interface import create_mesh_from_regions

from anuga.geospatial_data.geospatial_data import *

# Application specific imports
import project                 # Definition of file names and polygons



#------------------------------------------------------------------------------
# Copy scripts to time stamped output directory and capture screen
# output to file
#------------------------------------------------------------------------------

# filenames
meshname = project.meshname+'.msh'
source_dir = project.boundarydir


# creates copy of code in output dir if dir doesn't exist
if access(project.outputtimedir,F_OK) == 0:
    mkdir (project.outputtimedir)
copy (dirname(project.__file__) +sep+ project.__name__+'.py',
      project.outputtimedir + project.__name__+'.py')
copy (__file__, project.outputtimedir + basename(__file__))
print 'project.outputtimedir',project.outputtimedir



#--------------------------------------------------------------------------
# Create the triangular mesh based on overall clipping polygon with a
# tagged
# boundary and interior regions defined in project.py along with
# resolutions (maximal area of per triangle) for each polygon
#--------------------------------------------------------------------------


interior_regions = [#[project.karratha_polygon, 25000],
                    #[project.dampier_polygon, 2000],
                    #[project.refinery_polygon, 2000],
                    #[project.point_polygon, 2000]]
                    [project.neil1_polygon, 4000],
                    [project.neil2_polygon, 64000]]



print 'start create mesh from regions'
meshname = project.meshname + '.msh'
create_mesh_from_regions(project.bounding_polygon,
                         boundary_tags={'back': [7, 8], 'side': [0, 6],
                                        'ocean': [1, 2, 3, 4, 5]},
                         maximum_triangle_area=200000,
                         filename=meshname,
                         use_cache=True,
                         verbose=True)

#-------------------------------------------------------------------------
# Setup computational domain
#-------------------------------------------------------------------------
domain = Domain(meshname, use_cache=True, verbose=True)
print domain.statistics()
domain.set_name(project.basename)
domain.set_datadir(project.outputtimedir)


#-------------------------------------------------------------------------
# Setup initial conditions
#-------------------------------------------------------------------------
tide = 0.
domain.set_quantity('stage', tide)
domain.set_quantity('friction', 0.0) 
domain.set_quantity('elevation', 
                    filename = project.datadir + project.basename + '.pts',
                    use_cache = False,
                    verbose = True,
                    alpha = 0.1)

#-------------------------------------------------------------------------
# Setup boundary conditions 
#-------------------------------------------------------------------------

print 'Available boundary tags', domain.get_boundary_tags()

Bf = File_boundary(source_dir + project.boundary_basename + '.sww',
                   domain, verbose = True)
Br = Reflective_boundary(domain)
Bd = Dirichlet_boundary([tide,0,0])
domain.set_boundary({'back': Br,
                     'side': Bd,
                     'ocean': Bf}) 


#----------------------------------------------------------------------------
# Evolve system through time
#----------------------------------------------------------------------------
import time
t0 = time.time()

for t in domain.evolve(yieldstep = 60, finaltime = 28600):
    domain.write_time()
    domain.write_boundary_statistics(tags = 'ocean')     
    
print 'That took %.2f seconds' %(time.time()-t0)

